package
Version:
v0.0.0-...-808b117
Opens a new window with list of versions in this module.
Published: Dec 31, 2020
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
type User struct {
ID int64 `json:"id"`
FirstName string `json:"first_name"`
LastName string `json:"last_name"`
Email string `json:"email"`
DateCreated string `json:"date_created"`
}
User ...
Source Files
¶
Click to show internal directories.
Click to hide internal directories.